// HTTP Portion
var http = require('http');
var fs = require('fs'); // Using the filesystem module
var httpServer = http.createServer(requestHandler);
httpServer.listen(8080);

function requestHandler(req, res) {
	// Read index.html
	fs.readFile(__dirname + '/index.html', 
		// Callback function for reading
		function (err, data) {
			// if there is an error
			if (err) {
				res.writeHead(500);
				return res.end('Error loading index.html');
			}
			// Otherwise, send the data, the contents of the file
			res.writeHead(200);
			res.end(data);
  		}
  	);
}


// WebSocket Portion
// WebSockets work with the HTTP server
var io = require('socket.io').listen(httpServer);

// Register a callback function to run when we have an individual connection
// This is run for each individual user that connects
io.sockets.on('connection', 
	// We are given a websocket object in our function
	function (socket) {
	
		console.log("We have a new client: " + socket.id);
	
		// When this user "send" from clientside javascript, we get a "message"
		// client side: socket.send("the message");  or socket.emit('message', "the message");
		socket.on('message', 
			// Run this function when a message is sent
			function (data) {
				console.log("message: " + data);
				
				// Call "broadcast" to send it to all clients (except sender), this is equal to
				// socket.broadcast.emit('message', data);
				socket.broadcast.send(data);
				
				// To all clients, on io.sockets instead
				// io.sockets.emit('message', "this goes to everyone");
			}
		);
		
		// When this user emits, client side: socket.emit('otherevent',some data);
		socket.on('otherevent', function(data) {
			// Data comes in as whatever was sent, including objects
			console.log("Received: 'otherevent' " + data);
		});
		
		
		socket.on('disconnect', function() {
			console.log("Client has disconnected");
		});
	}
);		

var makeRequest = function() {
        var httprequestoptions = {
                host: '128.122.98.22',
                path: '/arduino/analog/0'
        };

        var callback  = function(response) {
                // This string will contain everything back from the server but it will come in chunks
                var str = '';

                // Got a chunk
                response.on('data', function (chunk) {
                        str += chunk;
                });

                response.on('end', function () {
                		// We are done
                		console.log(str);
                		
                		// Broadcast it
                		io.sockets.emit('sensor', str);
                		
                		// Request it again after a timeout
					var request = setTimeout(makeRequest,1000);
                });
        }

		// This is the actual request for the page
        http.request(httprequestoptions, callback).end();       
}; 

makeRequest();















        
        
        
        
        
        
        
        
        
        
        
        
